==> xlog_1.2.1.tar.gz: xlog-1.2.1/src/callbacks_preferencesdialog.h <==
/*
 * xlog - GTK+ logging program for amateur radio operators
 * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * callbacks_preferencesdialog.h
 */

void set_autosave (gint value, gint saving);
void set_theme (gchar * color, gchar * font, gboolean alsoforlog);
void set_path (gchar * pathstr);
void set_backuppath (gchar * pathstr);
void set_logstoload (gchar * logs);
void set_qthlocator (gchar * locator);
void set_callsign (gchar * callsign);
void set_clock (gboolean on);
gint whichhamlibwidgets (gboolean frequency, gboolean smeter);

#if WANT_HAMLIB
gboolean hamlib_changed (gint hamlibwidgets, gchar *radio, gchar *device, 
	gint polltime, gchar *rigconf);
#endif

void on_backupradiobutton_toggled (GtkToggleButton * togglebutton,
	gpointer user_data);
void on_bandsradiobutton_toggled (GtkToggleButton * togglebutton,
	gpointer user_data);
void on_modesradiobutton_toggled (GtkToggleButton * togglebutton,
	gpointer user_data);
void on_hamlibcheckbutton_toggled (GtkToggleButton * togglebutton,
	gpointer user_data);
void on_autosaveradiobutton_toggled(GtkToggleButton * togglebutton,
	gpointer user_data);
void on_pollingcheckbutton_toggled (GtkToggleButton *togglebutton,
	gpointer user_data);

==> xlog_1.3.1.orig.tar.gz: xlog-1.3.1.orig/src/callbacks_preferencesdialog.h <==
/*
 * xlog - GTK+ logging program for amateur radio operators
 * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * callbacks_preferencesdialog.h
 */

void set_autosave (gint value, gint saving);
void set_path (gchar * pathstr);
void set_backuppath (gchar * pathstr);
void set_logstoload (gchar * logs);
void set_qthlocator (gchar * locator);
void set_callsign (gchar * callsign);
void set_clock (gboolean on);
gint whichhamlibwidgets (gboolean frequency, gboolean smeter);

#if WANT_HAMLIB
gboolean hamlib_changed (gint hamlibwidgets, gint rigid, gchar *device, 
	gint polltime, gchar *rigconf);
#endif

void on_backupradiobutton_toggled (GtkToggleButton * togglebutton,
	gpointer user_data);
void on_bandsradiobutton_toggled (GtkToggleButton * togglebutton,
	gpointer user_data);
void on_modesradiobutton_toggled (GtkToggleButton * togglebutton,
	gpointer user_data);
void on_hamlibcheckbutton_toggled (GtkToggleButton * togglebutton,
	gpointer user_data);
void on_autosaveradiobutton_toggled(GtkToggleButton * togglebutton,
	gpointer user_data);
void on_pollingcheckbutton_toggled (GtkToggleButton *togglebutton,
	gpointer user_data);
void on_radiobutton_clicked (GtkButton * button, gpointer user_data);
